Module cache

Module cache 

Structs

CacheLog
CacheLog keeps track of the original and current values of each key accessed. By tracking original values, we can detect and eliminate write patterns where a key is changed temporarily and then reset to its original value

Enums

ReadError
ValueExists
Cache entry can be in three states: